#
# spec file for package python-argon2-cffi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-argon2-cffi
Version:        23.1.0
Release:        bp156.1.1
Summary:        The Argon2 password hashing algorithm for Python
License:        MIT
URL:            https://github.com/hynek/argon2_cffi
Source:         https://files.pythonhosted.org/packages/source/a/argon2-cffi/argon2_cffi-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module hatch-fancy-pypi-readme}
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# For test
BuildRequires:  %{python_module argon2-cffi-bindings}
Requires:       python-argon2-cffi-bindings
Provides:       python-argon2_cffi = %{version}
Obsoletes:      python-argon2_cffi < %{version}
BuildArch:      noarch
%python_subpackages

%description
A Python module that uses CFFI to access the Argon2 password hashing
C library.

%prep
%autosetup -p1 -n argon2_cffi-%{version}

%build
export ARGON2_CFFI_USE_SYSTEM=1
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.md FAQ.md README.md
%license LICENSE
%{python_sitelib}/argon2
%{python_sitelib}/argon2_cffi-%{version}.dist-info

%changelog
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 23.1.0:
  * The only new feature is the possibility to pass an own salt
    to `argon2.PasswordHasher.hash()`, however a lot has changed
    around documentation and packaging to make *argon2-cffi*
    maintainable in the future.
  * Python 3.6 is not supported anymore.
  * The `InvalidHash` exception is deprecated in favor of
    `InvalidHashError`. No plans for removal currently exist and
    the names can (but shouldn't) be used interchangeably.
  * `argon2.hash_password()`, `argon2.hash_password_raw()`, and
    `argon2.verify_password()` that have been soft-deprecated
    since 2016 are now hard-deprecated. They now raise
    `DeprecationWarning`s and will be removed in 2024.
  * Official support for Python 3.11 and 3.12. No code changes
    were necessary.
  * `argon2.exceptions.InvalidHashError` as a replacement for
    `InvalidHash`.
  * *salt* parameter to `argon2.PasswordHasher.hash()` to allow
    for custom salts. This is only useful for specialized use-
    cases -- leave it on None unless you know exactly what you
    are doing. \#153
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Mar 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed dependency six
* Fri May  6 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 21.3.0
  * Feature: Full type hints.
  * Adjusted defaults to RFC 9106 and support for pre-configured profiles.
  * Python 3.5 is not supported anymore.
  * The CFFI bindings have been extracted into a separate project:
    argon2-cffi-bindings
  * Added: argon2.Parameters.from_parameters() together with the
    argon2.profiles module that offers easy access to the RFC-recommended
    configuration parameters and then some.
  * The CLI interface now has a --profile option that takes any name
    from argon2.profiles.
  * argon2.PasswordHasher now uses the RFC 9106 low-memory profile
    by default. The old defaults are available as argon2.profiles.PRE_21_2.
* Sun Nov 14 2021 Michael Ströder <michael@stroeder.com>
- Update to 21.1.0
- skip building for Python 2 because not supported anymore
* Tue Jul 28 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 20.1.0:
  * It is now possible to manually override the detection of SSE2 using
    the ``ARGON2_CFFI_USE_SSE2`` environment variable.
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Jan 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 19.2.0
  * Python 3.4 is not supported anymore.
  * The dependency on enum34 is now protected using a PEP 508 marker.
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip test that randomly fails in obs test_argument_ranges
* Mon Apr  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Provide argon2_cffi namespace too
* Tue Feb 19 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v19.1.0
  * Vendoring Argon2 @ 670229c
  * Added support for Argon2 v1.2 hashes in argon2.extract_parameters()
- from 18.3.0
  * Vendoring Argon2 @ 670229c
  * argon2.PasswordHasher's hash type is now configurable
- from 18.2.0
  * Vendoring Argon2 @ 670229c
  * The hash type for ``argon2.PasswordHasher`` is Argon2\ **id** now.
    This decision has been made based on the recommendations in the latest
    Argon2 RFC draft
  * To make the change of hash type backward compatible,
    argon2.PasswordHasher.verify() now determines the type of the hash and
    verifies it accordingly
  * Some of the hash parameters have been made stricter to be closer to said
    recommendations. The current goal for a hash verification times is around 50ms
  * To allow for bespoke decisions about upgrading Argon2 parameters, it's now
    possible to extract them from a hash via argon2.extract_parameters()
  * Additionally argon2.PasswordHasher now has a check_needs_rehash() method
    that allows to verify whether a hash has been created with the instance's
    parameters or whether it should be rehashed
* Wed Aug  8 2018 jengelh@inai.de
- Ensure neutrality of description.
* Wed Aug  8 2018 tchvatal@suse.com
- Do not use bundled argon2
* Wed Aug  8 2018 tchvatal@suse.com
- Initial package for v18.1.0, used by Django
